@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -39,7 +39,7 @@ use WebDyne::Util;
 
 #  Version information
 #
-$VERSION='2.038';
+$VERSION='2.042';
 
 
 #  Debug load
@@ -376,7 +376,7 @@ sub compile {
     
     #  And look for any static or cache tags found in start_html and noted 
     #
-    foreach my $attr (qw(static cache)) {
+    foreach my $attr (qw(static cache handler)) {
         if (my $value=$html_tiny_or->{"_${attr}"}) {
             $meta{$attr}=$value;
         }
