@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -16,7 +16,7 @@ package WebDyne::Constant;
 #  Pragma
 #
 use strict qw(vars);
-use vars   qw($VERSION %Constant);
+use vars   qw($VERSION %Constant %Package);
 use warnings;
 no warnings qw(uninitialized);
 
@@ -32,7 +32,7 @@ require Opcode;
 
 #  Version information
 #
-$VERSION='2.038';
+$VERSION='2.042';
 
 
 #  Get mod_perl version taking intio account legacy strings. Clear $@ after evals
@@ -159,17 +159,39 @@ my %constant_temp;
     WEBDYNE_DUMP_FLAG => 0,
 
 
+    #  Encoding
+    #
+    WEBDYNE_HTML_CHARSET => do {
+        $constant_temp{'webdyne_html_charset'}='UTF-8'
+    },
+
+
     #  Content-type for text/html. Combined with charset to produce Content-type header
     #
     WEBDYNE_CONTENT_TYPE_HTML => do {
         $constant_temp{'webdyne_content_type_html'}='text/html'
     },
+    WEBDYNE_CONTENT_TYPE_HTML_ENCODED => do {
+        $constant_temp{'webdyne_content_type_html_encoded'}=sprintf('%s; charset=%s', @constant_temp{qw(webdyne_content_type_html webdyne_html_charset)})
+    },
 
 
     #  Content-type for text/plain. As above
     #
-    WEBDYNE_CONTENT_TYPE_TEXT => 'text/plain',
-    WEBDYNE_CONTENT_TYPE_JSON => 'application/json',
+    WEBDYNE_CONTENT_TYPE_TEXT => do {
+        $constant_temp{'webdyne_content_type_text'}='text/plain'
+    },
+    WEBDYNE_CONTENT_TYPE_TEXT_ENCODED => 
+        sprintf('%s; charset=%s', @constant_temp{qw(webdyne_content_type_text webdyne_html_charset)}),
+
+
+    #  And JSON
+    #
+    WEBDYNE_CONTENT_TYPE_JSON => do {
+        $constant_temp{'webdyne_content_type_json'}='application/json'
+    },
+    WEBDYNE_CONTENT_TYPE_JSON_ENCODED => 
+        sprintf('%s; charset=%s', @constant_temp{qw(webdyne_content_type_json webdyne_html_charset)}),
     
     
     #  Script types which are executable so we won't subst strings in them
@@ -180,12 +202,6 @@ my %constant_temp;
         module
     )},
 
-    #  Encoding
-    #
-    WEBDYNE_HTML_CHARSET => do {
-        $constant_temp{'webdyne_html_charset'}='UTF-8'
-    },
-
 
     #  DTD to use when generating HTML
     #
@@ -386,7 +402,8 @@ my %constant_temp;
     #
     WEBDYNE_HTTP_HEADER => {
 
-        'Content-Type'              => sprintf('%s; charset=%s', @constant_temp{qw(webdyne_content_type_html webdyne_html_charset)}),
+        #'Content-Type'              => sprintf('%s; charset=%s', @constant_temp{qw(webdyne_content_type_html webdyne_html_charset)}),
+        'Content-Type'              => $constant_temp{'webdyne_content_type_html_encoded'},
         'Cache-Control'             => 'no-cache, no-store, must-revalidate',
         'Pragma'                    => 'no-cache',
         'Expires'                   => '0',
@@ -437,9 +454,21 @@ my %constant_temp;
     WEBDYNE_DIR_CONFIG => undef,
     
     
-    #  Local constant path names
+    #  Dir_config can be loaded from each directory via webdyne.conf.pl 
+    #  if desired, only under Plack at the moment
     #
-    WEBDYNE_LOCAL_CONSTANT_FN => &local_constant_pn(),
+    WEBDYNE_DIR_CONFIG_CWD_LOAD => 1,
+    
+    
+    #  Local constant path names. Used as marker only, updated dynamically
+    #  by &local_constant_load;
+    #
+    WEBDYNE_CONF_HR => undef,
+    
+    
+    #  Config file name
+    #
+    WEBDYNE_CONF_FN => 'webdyne.conf.pl',
 
 
     #  Mod_perl level. Do not change unless you know what you are
@@ -452,143 +481,29 @@ my %constant_temp;
 );
 
 
-sub local_constant_load {
-
-
-    #  Load constants from override files first
-    #
-    my ($class, $constant_hr)=@_;
-    $constant_hr=\%{"${class}::Constant"};
-    
-    if ($constant_temp{$class}++) {
-        debug("class: $class, local_constant_load already performed, skipping");
-        return;
-    }
-    else {
-        debug("class: $class, constant_hr %s", Dumper($constant_hr));
-    }
-    my $local_constant_pn_ar=&local_constant_pn();
-    debug("local_constant_pn_ar: %s", Dumper($local_constant_pn_ar));
-    foreach my $local_constant_pn (@{$local_constant_pn_ar}) {
-        debug("load local_constant_pn: $local_constant_pn");
-        my $local_hr=(-f $local_constant_pn) && (
-            do(File::Spec->rel2abs($local_constant_pn))
-            ||
-            warn "unable to read local constant file, $!"
-        );
-        debug("local_hr $local_hr") if $local_hr;
-        if (my $hr=$local_hr->{$class}) {
-            debug("found class $class hr %s", Dumper($hr));
-            while (my ($key, $val)=each %{$hr}) {
-                $constant_hr->{$key}=$val;
-            }
-        }
-    }
-
-
-    #  Now from environment vars - override anything in config file
-    #
-    foreach my $key (keys %{$constant_hr}) {
-        if (defined $ENV{$key}) {
-            my $val=$ENV{$key};
-            debug("using environment value $val for key: $key");
-            $constant_hr->{$key}=$val;
-        }
-    }
-
-
-    #  Then command line
-    #
-    #GetOptions($constant_hr, map { "$_=s" } keys %{$constant_hr});
-
-
-    #  Load up Apache config - only if running under mod_perl
-    #
-    if ($MP_version) {
-
-
-        #  Ignore die's for the moment so don't get caught by error handler
-        #
-        debug("detected mod_perl version $MP_version - loading Apache directives");
-        local $SIG{'__DIE__'}=undef;
-        my $server_or;
-        eval {
-            #  Modern mod_perl 2
-            require Apache2::ServerUtil;
-            require APR::Table;
-            $server_or=Apache2::ServerUtil->server();
-        };
-        $@ && eval {
-
-            #  Interim mod_perl 1.99x
-            require Apache::ServerUtil;
-            require APR::Table;
-            $server_or=Apache::ServerUtil->server();
-        };
-        $@ && eval {
-
-            #  mod_perl 1x ?
-            require Apache::Table;
-            $server_or=Apache->server();
-        };
-
-        #  Clear any eval errors, set via dir_config now (overrides env)
-        #
-        $@ && do {
-            eval {undef}; errclr()
-        };
-        debug("loaded server_or: $server_or");
-        if ($server_or) {
-            my $table_or=$server_or->dir_config();
-            while (my ($key, $val)=each %{$table_or}) {
-                debug("installing value $val for Apache directive: $key");
-                $constant_hr->{$key}=$val if exists $constant_hr->{$key};
-            }
-        }
-    }
-
-
-    #  Is charset defined ? If so combine into content-type header
-    #
-    if (my $charset=$constant_hr->{'WEBDYNE_CHARSET'}) {
-        $constant_hr->{'WEBDYNE_CONTENT_TYPE_HTML'}=sprintf("%s; charset=$charset", $constant_hr->{'WEBDYNE_CONTENT_TYPE_HTML'})
-            unless $constant_hr->{'WEBDYNE_CONTENT_TYPE_HTML'}=~/charset=/;
-        $constant_hr->{'WEBDYNE_CONTENT_TYPE_TEXT'}=sprintf("%s; charset=$charset", $constant_hr->{'WEBDYNE_CONTENT_TYPE_TEXT'})
-            unless $constant_hr->{'WEBDYNE_CONTENT_TYPE_TEXT'}=~/charset=/;
-        $constant_hr->{'WEBDYNE_CONTENT_TYPE_JSON'}=sprintf("%s; charset=$charset", $constant_hr->{'WEBDYNE_CONTENT_TYPE_JSON'})
-            unless $constant_hr->{'WEBDYNE_CONTENT_TYPE_JSON'}=~/charset=/;
-    }
-
-
-    #  Done - return constant hash ref
-    #
-    $constant_hr;
-
-}
-
-
-sub local_constant_pn {
+sub local_constant_fn {
 
 
     #  Where local constants reside
     #
-    my @local_constant_pn;
-    my $local_constant_fn='webdyne.conf.pl';
+    my @local_constant_fn;
+    my $local_constant_fn=$Constant{'WEBDYNE_CONF_FN'};
     if ($^O=~/MSWin[32|64]/) {
         my $dn=$ENV{'WEBDYNE_HOME'} || $ENV{'WEBDYNE'} || $ENV{'WINDIR'};
-        push @local_constant_pn, ($ENV{'WEBDYNE_CONF'} || 
+        push @local_constant_fn, ($ENV{'WEBDYNE_CONF'} || 
             File::Spec->catfile($dn, $local_constant_fn))
     }
     else {
-        push @local_constant_pn, ($ENV{'WEBDYNE_CONF'} || 
+        push @local_constant_fn, ($ENV{'WEBDYNE_CONF'} || 
             File::Spec->catfile(
                 File::Spec->rootdir(), 'etc', $local_constant_fn
         ))
     }
     unless ($ENV{'WEBDYNE_CONF'}) {
-        push @local_constant_pn, glob(sprintf('~/.%s', $local_constant_fn));
+        push @local_constant_fn, glob(sprintf('~/.%s', $local_constant_fn));
     }
-    return \@local_constant_pn;
+    debug('local_constant_fn: %s, env: %s', Dumper(\@local_constant_fn, \%ENV));
+    return \@local_constant_fn;
 
 }
 
@@ -634,98 +549,327 @@ sub hashref {
 }
 
 
+
+sub local_constant_load {
+
+
+    #  Load constants from override files.
+    #
+    my ($class, $local_constant_fn)=@_;
+    debug("class: $class, local_constant_fn: $local_constant_fn");
+    
+    
+    #  Var to hold hash ref we load
+    #
+    my $constant_hr;
+    
+    
+    #  Now load, making sure we don't reload already loaded file - with bonus of creating
+    #  var that tracks/shows loaded files - WEBDYNE_CONF_HR
+    #
+    debug("attempt load local_constant_fn: $local_constant_fn");
+    if (-f $local_constant_fn && !$Constant{'WEBDYNE_CONF_HR'}{$local_constant_fn}++) {
+    #if (-f $local_constant_fn && !$Package{'file'}{$local_constant_fn}++) {
+        debug("file exists, about to load from: $local_constant_fn (%s)", File::Spec->rel2abs($local_constant_fn));
+        $Constant{'WEBDYNE_CONF_HR'}{$local_constant_fn}++;
+        $constant_hr=do(File::Spec->rel2abs($local_constant_fn)) ||
+            warn("unable to read local constant file, $!"); 
+    }
+
+
+    #  Now from environment vars - override anything in config file
+    #
+    foreach my $key (keys %{$constant_hr}) {
+        if (defined $ENV{$key}) {
+            my $val=$ENV{$key};
+            debug("using environment value $val for key: $key");
+            $constant_hr->{$key}=$val;
+        }
+    }
+
+
+    #  Load up Apache config - only if running under mod_perl
+    #
+    if (my $server_or=&server_or()) {
+        my $table_or=$server_or->dir_config();
+        while (my ($key, $val)=each %{$table_or}) {
+            debug("installing value $val for Apache directive: $key");
+            $constant_hr->{$key}=$val if exists $constant_hr->{$key};
+        }
+    }
+
+
+    #  Done - return constant hash ref
+    #
+    return $constant_hr;
+
+}
+
+
+sub server_or {
+
+    
+    #  Get the apache server object if available
+    #
+    unless (exists($Package{'server_or'})) {
+    
+    
+        #  Var to hold any server object found
+        #
+        my $server_or;
+    
+    
+        #  Only do checks if running under mod_perl
+        #
+        if ($MP_version) {
+
+
+            #  Ignore die's for the moment so don't get caught by error handler
+            #
+            debug("detected mod_perl version $MP_version - loading Apache directives");
+            local $SIG{'__DIE__'}=undef;
+            my $server_or;
+            eval {
+                #  Modern mod_perl 2
+                require Apache2::ServerUtil;
+                require APR::Table;
+                $server_or=Apache2::ServerUtil->server();
+            };
+            $@ && eval {
+
+                #  Interim mod_perl 1.99x
+                require Apache::ServerUtil;
+                require APR::Table;
+                $server_or=Apache::ServerUtil->server();
+            };
+            $@ && eval {
+
+                #  mod_perl 1x ?
+                require Apache::Table;
+                $server_or=Apache->server();
+            };
+
+            #  Clear any eval errors, set via dir_config now (overrides env)
+            #
+            $@ && do {
+                eval {undef}; errclr()
+            };
+            debug("loaded server_or: $server_or");
+            
+        }
+        else {
+            debug('skip server_or load, not running under mod_perl');
+        }
+        
+        
+        #  Save away so don't have to do this again
+        #
+        $Package{'server_or'}=$server_or;
+        
+    }
+    
+    
+    #  Return it
+    #
+    return $Package{'server_or'};
+    
+}
+
+
 sub import {
     
+
     #  Get caller
     #
-    my $class=shift();
+    my ($class, $local_constant_fn)=@_;
     
     
-    #  Return if already loaded
+    #  Check for dump flag, reserved word
     #
-    (my $class_fn=$class)=~s{::}{/}g;
-    $class_fn.='.pm';
-    #return if $INC{$class_fn};
+    my $dump_fg;
+    if (($local_constant_fn ||= '') eq 'dump') {
+        $dump_fg++;
+        $local_constant_fn=undef;
+    }
     
     
-    #  Load local constants file
+    #  Get array of local files also
     #
-    #unless ($INC{$class_fn}) {
-        &local_constant_load($class);
-    #}
+    my $local_constant_fn_ar=&local_constant_fn();
+    debug("local_constant_fn_ar: %s", Dumper($local_constant_fn_ar));
     
     
-    #  Get hash ref of Constants file from class calling up, calling
+    #  Load files if neccessary, get hash of constants to be applied
+    #
+    my @class_constant_hr;
+    foreach my $fn (grep {$_} (@{$local_constant_fn_ar}, $local_constant_fn)) {
+        
+        
+        #  Don't process twice
+        #
+        my $fn_hr=$Package{'import'}{$fn} ||= do {
+        
+            #  Need to load in file, haven't seen it yet/
+            #
+            debug("loading file: $fn");
+            
+        
+            #  If here need to read hash ref in from file
+            #
+            &local_constant_load($class, $fn);
+            
+        };
+        debug("local_constant_load hr: $fn_hr, %s", Dumper($fn_hr));
+        
+        
+        #  Any constants for this class into array for loading
+        #
+        if (my $class_constant_hr=$fn_hr->{$class}) {
+            
+            
+            #   Yes, save for later processing
+            #
+            debug("adding class_constant_hr: $class_constant_hr for processing, %s", Dumper($class_constant_hr));
+            push @class_constant_hr, $class_constant_hr;
+            
+        }
+        else {
+            
+            debug("skip $fn, no class: $class component in hash ref");
+            
+        }
+        
+    }
+
+    
+    #  Debug what we have
+    #
+    debug('class_constant_hr: %s', Dumper(\@class_constant_hr));
+        
+    
+    #  Get hash ref of Constants file from class calling us - calling
     #  module needs to declare a %Class:Name::Constant variable in 
     #  global space.
     #
-    my $hr=\%{"${class}::Constant"};
+    my $class_constant_hr=\%{"${class}::Constant"};
+    
+
+    #  We want to load variable into namespace. Get the parent class and who is
+    #  calling us/
+    #
+    (my $class_parent=$class)=~s/::Constant$//;
+    my $caller = caller(0);
+    debug("caller: $caller");        
+    
+    
+    #  Remember caller
+    #
+    $Package{'caller'}{$class}{$caller}++;
+    
+
+    #  Now start iterating over and loading
+    #
+    foreach $caller (keys %{$Package{'caller'}{$class}}) {
+        foreach my $constant_hr ($class_constant_hr, @class_constant_hr) {
+        
+
+            #  Now iterate across all callers and load vars into namespace. Turn off warnings as
+            #  we may have to redefine some variables
+            #
+            no warnings qw(once redefine);
+            debug("importing for caller: $caller");
+            
+            
+            #  Don't load hash ref into caller if already done
+            #
+            if ($Package{'caller'}{$caller}{$constant_hr}++) {
+                debug("skip, already applied $constant_hr to caller: $caller");
+                next;
+            }
+            else {
+                debug('continue');
+            }
+            
+            
+            #  Start iterating over all constants in class 
+            #
+            while (my($k, $v)=each %{$class_constant_hr}) {
+            
+                #  Override ?
+                #
+                if (defined($constant_hr->{$k}) && ($constant_hr ne $class_constant_hr)) {
+                
+                    #  Yes
+                    #
+                    debug("override constant_hr $k value: $v with file value: %s", $constant_hr->{$k});
+                    $v=$class_constant_hr->{$k}=$constant_hr->{$k};
+
+                }
+                debug("caller: $caller, class: $class  set:$k value:$v");
+
+
+                #  Used to do just
+                #  
+                # *{"${caller}::${k}"}=\$v;
+                #
+                #  Make a bit more sophisticated so if the
+                #  var is updated anywhere it is used all 
+                #  modules see + put a hash called Constant in
+                #  the parent module so we don't have to do
+                #
+                #  %WebDyne::Constant::Constant 
+                # 
+                #  now just
+                #
+                #  %WebDyne::Constant
+                #
+                if ($caller eq $class_parent) {
+                    *{"${caller}::${k}"}=\$v;
+                    #*{"${caller}::Constant"}=$hr; # Pulled for moment, bit polluting without ability to ref constant scalars in hash values
+                }
+                else {
+                    if (defined *{"${class_parent}::${k}"}) {
+                        *{"${caller}::${k}"} = *{"${class_parent}::${k}"};
+                    }
+                    else {
+                        *{"${caller}::${k}"} = \$v;
+                    }
+                    #  Used to be this                
+                    #*{"${caller}::${k}"}=\${"${class_parent}::${k}"};
+                }
+                debug("caller: $caller, set:$k value:$v");
+                #next if ref($v); # Not needed, stop Regexp conversion
+                if ($v=~/^\d+$/) {
+                    debug("using sub() ${caller}::${k}=$v");
+                    *{"${caller}::${k}"}=eval("sub () { $v }");
+                }
+                else {
+                    debug("fall through, using sub() ${caller}::${k}=q($v)");
+                    *{"${caller}::${k}"}=eval("sub () { q($v) }");
+                }
+                    
+            }
+        }
+    }
     
     
     #  Check if just dumping for view, or actually loading into caller
     #  namespace
     #
-    if (($_[0] ||= '') eq 'dump') {
+    if ($dump_fg) {
 
         #  We just to want to see what they are
         #
         local $Data::Dumper::Indent=1;
         local $Data::Dumper::Terse=1;
         local $Data::Dumper::Sortkeys=1;
-        CORE::print Dumper($hr);
+        CORE::print Dumper($class_constant_hr);
         exit 0;
     }
-    else {
-
-        #  We want to load variable into namespace. Get the parent class
-        #
-        (my $class_parent=$class)=~s/::Constant$//;
-        my $caller = caller(0);
-        debug("caller: $caller");
-        no warnings qw(once);
-        while (my($k, $v)=each %{$hr}) {
-            #  Used to do just
-            #  
-            # *{"${caller}::${k}"}=\$v;
-            #
-            #  Make a bit more sophisticated so if the
-            #  var is updated anywhere it is used all 
-            #  modules see + put a hash called Constant in
-            #  the parent module so we don't have to do
-            #
-            #  %WebDyne::Constant::Constant 
-            # 
-            #  now just
-            #
-            #  %WebDyne::Constant
-            #
-            if ($caller eq $class_parent) {
-                *{"${caller}::${k}"}=\$v;
-                #*{"${caller}::Constant"}=$hr; # Pulled for moment, bit polluting without ability to ref constant scalars in hash values
-            }
-            else {
-                if (defined *{"${class_parent}::${k}"}) {
-                    *{"${caller}::${k}"} = *{"${class_parent}::${k}"};
-                }
-                else {
-                    *{"${caller}::${k}"} = \$v;
-                }
-                #  Used to be this                
-                #*{"${caller}::${k}"}=\${"${class_parent}::${k}"};
-            }
-            next if *{"${caller}::${k}"}{'CODE'};
-            #next if ref($v); # Not needed, stop Regexp conversion
-            if ($v=~/^\d+$/) {
-                *{"${caller}::${k}"}=eval("sub () { $v }");
-            }
-            else {
-                *{"${caller}::${k}"}=eval("sub () { q($v) }");
-            }
-                
-        }
-    }
+    
 }
 
+
 1;
 
 
