@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is copyright (c) 2025 by Andrew Speer <andrew.speer@isolutions.com.au>.
+#  This software is copyright (c) 2026 by Andrew Speer <andrew.speer@isolutions.com.au>.
 #
 #  This is free software; you can redistribute it and/or modify it under
 #  the same terms as the Perl 5 programming language system itself.
@@ -42,7 +42,7 @@ require Exporter;
 
 #  Version information
 #
-$VERSION='2.038';
+$VERSION='2.042';
 
 
 #  Var to hold package wide hash, for data shared across package, and error stack
@@ -231,42 +231,43 @@ sub debug {
     #  Time in human readable format
     #
     my ($sec, $msec)=gettimeofday();
-
-    #my $timestamp=strftime("%Y-%m-%d %H:%M:%S", localtime($sec)) . sprintf(".%04d", $msec);
     my $timestamp=strftime("%H:%M:%S", localtime($sec)) . sprintf('.%06d', $msec);
 
 
     #  Get the debug message
     #
+    #local $SIG{__WARN__}=sub { die @_ };  #uncomment if want to trace any missing sprintf params
     my $debug=$#_ ? sprintf(shift(), @_) : shift();
 
 
     #  Filtering ?
     #
-    #if ($ENV{'WEBDYNE_DEBUG'} && ($ENV{'WEBDYNE_DEBUG'} ne '1')) {
     if ($Package{'WEBDYNE_DEBUG'} && ($Package{'WEBDYNE_DEBUG'} ne '1')) {
 
 
         #  Yes - check we are getting from caller we are interested in
         #
-        #my @debug_target=split(/[,;]/, $ENV{'WEBDYNE_DEBUG'});
         my @debug_target=split(/[,;]/, $Package{'WEBDYNE_DEBUG'});
         foreach my $debug_target (@debug_target) {
             if (($caller eq $debug_target) || ($method=~/\Q$debug_target\E$/)) {
-
-                #CORE::print $debug_fh "[$timestamp $subroutine] ", $_[1] ? sprintf(shift(), @_) : $_[0], $/;
-                #CORE::print $debug_fh "[$timestamp $subroutine] ", $debug, $/;
+            
+                #  Print debug after checking for any regexp wanted
+                #
+                if (my $regexp=$ENV{'WEBDYNE_DEBUG_FILTER'}) {
+                    next unless $debug=~qr/$regexp/;
+                }
                 CORE::print $debug_fh "[$timestamp $class ($subroutine)] ", $debug, $/;
             }
         }
     }
     else {
 
-        #  No filtering. Open floodgates
+        #  No filtering. Open floodgates but still apply any regexp
         #
-        #CORE::print $debug_fh "[$timestamp $subroutine] ", $_[1] ? sprintf(shift(), @_) : $_[0], $/;
-        #CORE::print $debug_fh "[$timestamp $subroutine] ", $debug, $/;
-        CORE::print $debug_fh "[$timestamp $class $subroutine] ", $debug, $/;
+        if (my $regexp=$ENV{'WEBDYNE_DEBUG_FILTER'}) {
+            next unless $debug=~qr/$regexp/;
+        }
+        CORE::print $debug_fh "[$timestamp $class ($subroutine)] ", $debug, $/;
     }
 
 }
